
      subroutine correlate (array1, array2, npoints, rpower)
c******************************************************************************
c     This routine does the work of making a correlation statistic between
c     array1 and array2, which are npoints long; note that this routine
c     cannot check whether the real boundaries of the arrays are large
c     enough to do the calculations without crashing; this is done in the
c     calling routines, as are needed shifts between the arrays; the only
c     output is the correlation coefficient rpower 
c******************************************************************************

      implicit real*8 (a-h,o-z)
      real*8 array1(*), array2(*)


c*****initialize variables
      xsum = 0.
      ysum = 0.
      xysum = 0.
      x2sum = 0.
      y2sum = 0.
      xntot = real(npoints)


c*****compute sums and products
      do i=1,npoints
         xx = array1(i)
         yy = array2(i)
         xsum = xsum + xx
         ysum = ysum + yy
         xysum = xysum + xx*yy
         x2sum = x2sum + xx*xx
         y2sum = y2sum + yy*yy
      enddo


c*****compute covariance, variances, and correlation power
      covar = xntot*xysum - xsum*ysum
      varx = dsqrt(xntot*x2sum - xsum*xsum)
      vary = dsqrt(xntot*y2sum - ysum*ysum)
      rpower = covar/(varx*vary)


c*****exit normally
      return
      end



