
      program rrlyr
c******************************************************************************
c     this program derives metallicities for RR Lyr stars automatically
c******************************************************************************

      implicit real*8 (a-h,o-z)
      include 'obsquants.com'
      include 'synquants.com'
      include 'asciichars.com'
      include 'plotquants.com'
      include 'plotchars.com'
      real*8 tempchi2(1000)


c*****to begin, open a general summary output file, a summary file for
c*****the main results for all stars, and a gory details file for all stars
      open (98,file='rrsurvey.out',status='unknown')
      open (97,file='rrsurveysummmary.txt')
      write (97,1009) ((nint(chi2wave(i,j)),i=1,2),j=1,nchi2)
      open (96,file='rrsurveydetails.txt')
      write (96,1011) 


c*****to begin, open and read the file with paths, parameters, etc.
      call instructions


c*****read in the synthetic raw spectra, smooth them and save to arrays
      call getsynthetics


c*****read in each observed spectrum
      do i=1,10000
         call getobservations
         if (starname(1:25) .eq. 'NO OBSERVATION FILE FOUND') cycle
         if (starname(1:24) .eq. 'NO MORE OBSERVED SPECTRA') exit


c*****do the statistics on desired wavelength intervals
         sigmaclip = 4.
         call obsstats


c*****decide on the appropriate sigma estimates for yellow and blue regions
         call bestsigma


c*****use autocorrelation to give independent estimate of smoothing
         write (99,1004)
         wavelo = 4400.
         wavehi = 4600.
         call autocorr
         wavelo = 5150.
         wavehi = 5450.
         call autocorr


c*****compute the array of obsvered-synthetic spectrum differences
         call diffobssyn


c*****compute the chi2 statistics for each spectral region specified
c*****by the input file; then search for chi2 minima;
c*****plot the observed and synthetic spectra for the overall regions;
c*****usse only the two overall regions for these plots
         write (96,1012)
         do ichi2=1,nchi2
            call chi2create
            call chi2select
            kount = 0
            do k=1,nsyntot
               if (chi2noocdiff(k,ichi2) .gt. -90.) then
                  kount = kount + 1
                  tempchi2(kount) = chi2noocdiff(k,ichi2)
               endif
            enddo
            if (chi2wave(1,ichi2) .lt. 5000.) then
               snuse = 1./sigblu
            else
               snuse = 1./sigyel
            endif
            startmetal = metalmod(1)
            deltametal = 0.1
            write (96,1006) starname(1:18), nint(chi2wave(1,ichi2)), 
     .                      nint(chi2wave(2,ichi2)), numchi2pts,
     .                      snuse, startmetal, deltametal,
     .                      (tempchi2(k),k=1,kount)
            if (ichi2 .le. 2) call obssynplot
         enddo


c*****write out the statistics
         write (97,1010) nint(teffchi2(1)), loggchi2(1), 
     .                   vmicrochi2(1), (metalchi2(ichi2), 
     .                   chi2nomin(ichi2), ichi2=1,nchi2), 
     .                   1./sigblu, 1./sigyel, 
     .                   starname(1:40)


c*****plot the chi2 values for the overall regions
         call chi2plot
      enddo


c*****format statements
1004  format (/'AUTOCORRELATION HALF-POWER RESULTS:')
1009  format (' Teff logg   vt  [M/H]   chi2  [M/H]   chi2  ',
     .        '[M/H]   chi2  [M/H]   chi2   S/N  S/N        spectrum'/
     .        14x, 4(i9, '-',i4))
1010        format (i5, 2f5.2, 4(f7.2,f7.3), 2f6.1, 2x, a25)
1006  format (a18, 2i5, i7, f7.1, f10.1, f10.1, 2x, 100f6.3)
1011  format (5x, 'starname       lambdas    #pts    S/N',
     .        '  [M/H]beg  [M/H]del  ch2 array --->')
1012  format (' ')


      end


      
