
c***********************************************************************
      subroutine smoothsyns
c***********************************************************************
c     this routine smooths the raw syntheses; for now only Gaussian
c     smoothing is done; may add rotational smoothing in the future

      implicit real*8 (a-h,o-z)
      include 'infosyns.com'
      include 'quants.com'
      include 'asciichars.com'


c*****use the current model atmosphere info to compute approximate 
c*****thermal and microturbulent velocity widths; combine these with 
c*****vfwhmobs to get the synthetic spectrum smoothing
      vintrinsic = 2.*dsqrt(1.6631d-2*teff/56. + vt**2)
      vsmooth = vfwhmobs - vintrinsic
      wsmooth = vsmooth/3.0d+5*(synstart+synstop)/2.


c*****compute the Gaussian smoothing function
      sigma = wsmooth/2.
      aa = 0.6932/sigma**2
      gausspower = 1.0
      do k=1,1000
         pgauss(k) = dexp(-aa*(synstep*k)**2 )
         gausspower = gausspower + 2*pgauss(k)
         if (pgauss(k) .lt. 0.01) exit
      enddo
      ngauss = k
      if (ngauss .gt. nsynpoints/4) then
         write (*,1001) ngauss, nsynpoints/4
         stop
      endif


c*****apply this Gaussian to the raw syntheses
      do i=1,numsyns
         do j=1,ngauss
            smoothsyn(j,i) = 1.
            smoothsyn(nsynpoints+1-j,i) = 1.
         enddo
         do j=ngauss+1,nsynpoints-ngauss
            synsum = rawsyn(j,i)
            do k=1,ngauss
               synsum = synsum + pgauss(k)*
     .                  (rawsyn(j-k,i) + rawsyn(j+k,i))
            enddo
            smoothsyn(j,i) = synsum/gausspower
         enddo
      enddo


c*****exit normally
      return


c*****format statements
1001  format ('Gaussian profile covers the whole spectrum: '/
     .        'ngauss =', i5, ',  nsynpoints/4 =', i5, 'I QUIT!')

   
      end




